@@ -25,6 +25,7 @@ __all__ = ['all_eq',
            'inspect_special_values',
            'interruptible',
            'interruptible_if',
+           'isalias',
            'isclassattr',
            'isscalar',
            'least_greater_multiple',
@@ -65,8 +66,8 @@ def all_eq(a, b):
         if type(a) is not type(b):
             return False
         return a == b
-    if isinstance(a, (np.ndarray, np.number)) or \
-       isinstance(b, (np.ndarray, np.number)):
+    if isinstance(a, (float, np.ndarray, np.number)) or \
+       isinstance(b, (float, np.ndarray, np.number)):
         return np.allclose(a, b)
     if isinstance(a, collections.Container):
         if type(a) is not type(b):
@@ -401,6 +402,14 @@ def interruptible_if(condition):
         with interruptible():
             yield
 
+def isalias(array1, array2):
+    """
+    Return True if the two input arrays point to the same memory location.
+
+    """
+    return array1.__array_interface__['data'][0] == \
+           array2.__array_interface__['data'][0]
+
 def isclassattr(cls, a):
     """ Test if an attribute is a class attribute. """
     for c in cls.__mro__:
